# thinmam

This is a database of **solid thermophysical and mechanical properties**. It is implemented in *python*. 

## Installation:

python setup.py install --user

## Usage:

import thinmam

solstate = thinmam.state("SS")
